.. title:: Table of Contents

####################
CVXOPT User's Guide
####################

**Release 1.2.3 -- February 5, 2019**

**Martin Andersen, Joachim Dahl, and Lieven Vandenberghe**

.. toctree::

    copyright.rst
    intro.rst
    matrices.rst
    blas.rst
    lapack.rst
    fftw.rst
    spsolvers.rst
    coneprog.rst
    solvers.rst
    modeling.rst
    c-api.rst
    printing.rst
    cvxopt.org <http://cvxopt.org>
